import java.io.*;
import java.util.*;

public class sol_ik_40 {

    private final int UNIT = 1000;
    private final int DISCOUNT_PER_UNIT = 500;
    private final double MAX_DISCOUNT = 0.2;
    private final int INF = (int) 1e9;
    
    private boolean hasBit(int mask, int bit) {
        return (mask & (1 << bit)) != 0;
    }
    
    private int[] getMinForSubset(List<Integer> costs, int maxUnits) { 
        int[] res = new int[maxUnits + 1];
        Arrays.fill(res, INF);
        int n = costs.size();
        for (int mask = 0; mask < (1 << n); mask++) {
            int curUnits = 0;
            int curSum = 0;
            for (int b = 0; b < n; b++) {
                if (hasBit(mask, b)) {
                    curUnits += costs.get(b) / UNIT;
                    curSum += costs.get(b);
                }
            }
            res[curUnits] = Math.min(res[curUnits], curSum);
        }
        return res;
    }
    
    private int[] merge(int[] a, int[] b) {
        int[] c = new int[a.length];
        Arrays.fill(c, INF);
        for (int i = 0; i < a.length; i++) {
            for (int j = 0; i + j < b.length; j++) {
                c[i + j] = Math.min(c[i + j], a[i] + b[j]);
            }
        } 
        return c;
    }
    
    public double getSolution(List<Integer> costs) {
        int totalSum = 0;
        for (int elem : costs) {
            totalSum += elem;
        }
        int maxUnits = totalSum / UNIT;
        int n = costs.size();
        int[] minLeft = getMinForSubset(costs.subList(0, n / 2), maxUnits);
        int[] minRight = getMinForSubset(costs.subList(n / 2, n), maxUnits);
        int[] minForUnits = merge(minLeft, minRight);
        double res = totalSum;
        for (int units = 0; units <= maxUnits; units++) {
            if (minForUnits[units] == INF)
                continue;
            int first = minForUnits[units];
            int second = totalSum - first;
            double secondWithDiscount = second 
                    - Math.min(units * DISCOUNT_PER_UNIT, second * MAX_DISCOUNT);
            res = Math.min(res, first + secondWithDiscount);
        }
        return res;
    }
    
    public void solve(Scanner in, PrintWriter out) {
        int n = in.nextInt();
        List<Integer> costs = new ArrayList<>();
        for (int i = 0; i < n; i++) {
            costs.add(in.nextInt());
        }
        out.printf("%.10f%n", getSolution(costs));
    }
    
    public static void main(String[] args) {
        Scanner in = new Scanner(System.in);
        PrintWriter out = new PrintWriter(System.out);
        new sol_ik_40().solve(in, out);
        out.flush();
    } 
}
